Documentation
¶
Index ¶
- Variables
- func GetActiveMetaPage(path string) (*common.Meta, common.Pgid, error)
- func GetRootPage(path string) (root common.Pgid, activeMeta common.Pgid, err error)
- func ReadPage(path string, pageID uint64) (*common.Page, []byte, error)
- func ReadPageAndHWMSize(path string) (uint64, common.Pgid, error)
- func WritePage(path string, pageBuf []byte) error
Constants ¶
This section is empty.
Variables ¶
var ( // ErrCorrupt is returned when a checking a data file finds errors. ErrCorrupt = errors.New("invalid value") )
Functions ¶
func GetActiveMetaPage ¶ added in v1.4.0
GetActiveMetaPage returns the active meta page and its page ID (0 or 1).
func GetRootPage ¶
GetRootPage returns the root-page (according to the most recent transaction).
func ReadPage ¶
ReadPage reads Page info & full Page data from a path. This is not transactionally safe.
func ReadPageAndHWMSize ¶
ReadPageAndHWMSize reads Page size and HWM (id of the last+1 Page). This is not transactionally safe.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.